#[repr(C)]pub struct SLComposeServiceViewController { /* private fields */ }SLComposeServiceViewController and crate feature objc2-app-kit and macOS only.Expand description
Implementations
Sourceimpl SLComposeServiceViewController
impl SLComposeServiceViewController
pub unsafe fn presentationAnimationDidFinish(&self)
pub unsafe fn textView(&self) -> Option<Retained<NSTextView>>
pub unsafe fn contentText(&self) -> Option<Retained<NSString>>
pub unsafe fn placeholder(&self) -> Retained<NSString>
Sourcepub unsafe fn setPlaceholder(&self, placeholder: Option<&NSString>)
pub unsafe fn setPlaceholder(&self, placeholder: Option<&NSString>)
Setter for placeholder.
pub unsafe fn didSelectPost(&self)
pub unsafe fn didSelectCancel(&self)
pub unsafe fn cancel(&self)
pub unsafe fn isContentValid(&self) -> bool
pub unsafe fn validateContent(&self)
pub unsafe fn charactersRemaining(&self) -> Option<Retained<NSNumber>>
Sourcepub unsafe fn setCharactersRemaining(
&self,
characters_remaining: Option<&NSNumber>,
)
pub unsafe fn setCharactersRemaining( &self, characters_remaining: Option<&NSNumber>, )
Setter for charactersRemaining.
Sourceimpl SLComposeServiceViewController
Methods declared on superclass NSViewController.
impl SLComposeServiceViewController
Methods declared on superclass NSViewController.
Sourceimpl SLComposeServiceViewController
Methods declared on superclass NSResponder.
impl SLComposeServiceViewController
Methods declared on superclass NSResponder.
Sourceimpl SLComposeServiceViewController
Methods declared on superclass NSObject.
impl SLComposeServiceViewController
Methods declared on superclass NSObject.
pub unsafe fn new(mtm: MainThreadMarker) -> Retained<Self>
Methods from Deref<Target = NSViewController>
pub unsafe fn nibName(&self) -> Option<Retained<NSString>>
pub unsafe fn nibBundle(&self) -> Option<Retained<NSBundle>>
pub unsafe fn representedObject(&self) -> Option<Retained<AnyObject>>
Sourcepub unsafe fn setRepresentedObject(
&self,
represented_object: Option<&AnyObject>,
)
pub unsafe fn setRepresentedObject( &self, represented_object: Option<&AnyObject>, )
Setter for representedObject.
pub unsafe fn title(&self) -> Option<Retained<NSString>>
pub unsafe fn view(&self) -> Retained<NSView>
pub unsafe fn viewIfLoaded(&self) -> Option<Retained<NSView>>
pub unsafe fn loadView(&self)
pub unsafe fn loadViewIfNeeded(&self)
pub unsafe fn commitEditingWithDelegate_didCommitSelector_contextInfo( &self, delegate: Option<&AnyObject>, did_commit_selector: Option<Sel>, context_info: *mut c_void, )
pub unsafe fn commitEditing(&self) -> bool
pub unsafe fn discardEditing(&self)
pub unsafe fn viewDidLoad(&self)
pub unsafe fn isViewLoaded(&self) -> bool
pub unsafe fn viewWillAppear(&self)
pub unsafe fn viewDidAppear(&self)
pub unsafe fn viewWillDisappear(&self)
pub unsafe fn viewDidDisappear(&self)
pub unsafe fn preferredContentSize(&self) -> CGSize
Sourcepub unsafe fn setPreferredContentSize(&self, preferred_content_size: CGSize)
pub unsafe fn setPreferredContentSize(&self, preferred_content_size: CGSize)
Setter for preferredContentSize.
pub unsafe fn updateViewConstraints(&self)
pub unsafe fn viewWillLayout(&self)
pub unsafe fn viewDidLayout(&self)
pub unsafe fn presentViewController_animator( &self, view_controller: &NSViewController, animator: &ProtocolObject<dyn NSViewControllerPresentationAnimator>, )
pub unsafe fn dismissViewController(&self, view_controller: &NSViewController)
pub unsafe fn dismissController(&self, sender: Option<&AnyObject>)
pub unsafe fn presentedViewControllers( &self, ) -> Option<Retained<NSArray<NSViewController>>>
pub unsafe fn presentingViewController( &self, ) -> Option<Retained<NSViewController>>
pub unsafe fn presentViewControllerAsSheet( &self, view_controller: &NSViewController, )
pub unsafe fn presentViewControllerAsModalWindow( &self, view_controller: &NSViewController, )
pub unsafe fn parentViewController(&self) -> Option<Retained<NSViewController>>
pub unsafe fn childViewControllers(&self) -> Retained<NSArray<NSViewController>>
Sourcepub unsafe fn setChildViewControllers(
&self,
child_view_controllers: &NSArray<NSViewController>,
)
pub unsafe fn setChildViewControllers( &self, child_view_controllers: &NSArray<NSViewController>, )
Setter for childViewControllers.
pub unsafe fn addChildViewController( &self, child_view_controller: &NSViewController, )
pub unsafe fn removeFromParentViewController(&self)
pub unsafe fn insertChildViewController_atIndex( &self, child_view_controller: &NSViewController, index: isize, )
pub unsafe fn removeChildViewControllerAtIndex(&self, index: isize)
pub unsafe fn preferredContentSizeDidChangeForViewController( &self, view_controller: &NSViewController, )
pub unsafe fn viewWillTransitionToSize(&self, new_size: CGSize)
pub unsafe fn extensionContext(&self) -> Option<Retained<NSExtensionContext>>
pub unsafe fn sourceItemView(&self) -> Option<Retained<NSView>>
Sourcepub unsafe fn setSourceItemView(&self, source_item_view: Option<&NSView>)
pub unsafe fn setSourceItemView(&self, source_item_view: Option<&NSView>)
Setter for sourceItemView.
pub unsafe fn preferredScreenOrigin(&self) -> CGPoint
Sourcepub unsafe fn setPreferredScreenOrigin(&self, preferred_screen_origin: CGPoint)
pub unsafe fn setPreferredScreenOrigin(&self, preferred_screen_origin: CGPoint)
Setter for preferredScreenOrigin.
pub unsafe fn preferredMinimumSize(&self) -> CGSize
pub unsafe fn preferredMaximumSize(&self) -> CGSize
Methods from Deref<Target = NSResponder>
pub unsafe fn nextResponder(&self) -> Option<Retained<NSResponder>>
Sourcepub unsafe fn setNextResponder(&self, next_responder: Option<&NSResponder>)
pub unsafe fn setNextResponder(&self, next_responder: Option<&NSResponder>)
Setter for nextResponder.
pub unsafe fn tryToPerform_with( &self, action: Sel, object: Option<&AnyObject>, ) -> bool
pub unsafe fn noResponderFor(&self, event_selector: Sel)
pub unsafe fn acceptsFirstResponder(&self) -> bool
pub unsafe fn becomeFirstResponder(&self) -> bool
pub unsafe fn resignFirstResponder(&self) -> bool
pub unsafe fn flushBufferedKeyEvents(&self)
pub unsafe fn showContextHelp(&self, sender: Option<&AnyObject>)
pub unsafe fn supplementalTargetForAction_sender( &self, action: Sel, sender: Option<&AnyObject>, ) -> Option<Retained<AnyObject>>
pub unsafe fn undoManager(&self) -> Option<Retained<NSUndoManager>>
pub unsafe fn presentError(&self, error: &NSError) -> bool
pub unsafe fn willPresentError(&self, error: &NSError) -> Retained<NSError>
pub unsafe fn performTextFinderAction(&self, sender: Option<&AnyObject>)
pub unsafe fn newWindowForTab(&self, sender: Option<&AnyObject>)
pub unsafe fn showWritingTools(&self, sender: Option<&AnyObject>)
pub unsafe fn performMnemonic(&self, string: &NSString) -> bool
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<NSResponder> for SLComposeServiceViewController
impl AsRef<NSResponder> for SLComposeServiceViewController
Sourcefn as_ref(&self) -> &NSResponder
fn as_ref(&self) -> &NSResponder
Sourceimpl AsRef<NSViewController> for SLComposeServiceViewController
impl AsRef<NSViewController> for SLComposeServiceViewController
Sourcefn as_ref(&self) -> &NSViewController
fn as_ref(&self) -> &NSViewController
Sourceimpl Borrow<NSResponder> for SLComposeServiceViewController
impl Borrow<NSResponder> for SLComposeServiceViewController
Sourcefn borrow(&self) -> &NSResponder
fn borrow(&self) -> &NSResponder
Sourceimpl Borrow<NSViewController> for SLComposeServiceViewController
impl Borrow<NSViewController> for SLComposeServiceViewController
Sourcefn borrow(&self) -> &NSViewController
fn borrow(&self) -> &NSViewController
Sourceimpl ClassType for SLComposeServiceViewController
impl ClassType for SLComposeServiceViewController
Sourceconst NAME: &'static str = "SLComposeServiceViewController"
const NAME: &'static str = "SLComposeServiceViewController"
Sourcetype Super = NSViewController
type Super = NSViewController
Sourcetype ThreadKind = <<SLComposeServiceViewController as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<SLComposeServiceViewController as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl NSEditor for SLComposeServiceViewController
impl NSEditor for SLComposeServiceViewController
unsafe fn discardEditing(&self)
unsafe fn commitEditing(&self) -> bool
unsafe fn commitEditingWithDelegate_didCommitSelector_contextInfo( &self, delegate: Option<&AnyObject>, did_commit_selector: Option<Sel>, context_info: *mut c_void, )
unsafe fn commitEditingAndReturnError(&self) -> Result<(), Retained<NSError>>
Sourceimpl NSObjectProtocol for SLComposeServiceViewController
impl NSObjectProtocol for SLComposeServiceViewController
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_refSourcefn isMemberOfClass(&self, cls: &AnyClass) -> bool
fn isMemberOfClass(&self, cls: &AnyClass) -> bool
Sourcefn respondsToSelector(&self, aSelector: Sel) -> bool
fn respondsToSelector(&self, aSelector: Sel) -> bool
Sourcefn conformsToProtocol(&self, aProtocol: &AnyProtocol) -> bool
fn conformsToProtocol(&self, aProtocol: &AnyProtocol) -> bool
Sourcefn debugDescription(&self) -> Retained<NSObject>
fn debugDescription(&self) -> Retained<NSObject>
Sourceimpl NSSeguePerforming for SLComposeServiceViewController
impl NSSeguePerforming for SLComposeServiceViewController
unsafe fn prepareForSegue_sender( &self, segue: &NSStoryboardSegue, sender: Option<&AnyObject>, )
unsafe fn performSegueWithIdentifier_sender( &self, identifier: &NSString, sender: Option<&AnyObject>, )
unsafe fn shouldPerformSegueWithIdentifier_sender( &self, identifier: &NSString, sender: Option<&AnyObject>, ) -> bool
Sourceimpl NSTextDelegate for SLComposeServiceViewController
impl NSTextDelegate for SLComposeServiceViewController
unsafe fn textShouldBeginEditing(&self, text_object: &NSText) -> bool
unsafe fn textShouldEndEditing(&self, text_object: &NSText) -> bool
unsafe fn textDidBeginEditing(&self, notification: &NSNotification)
unsafe fn textDidEndEditing(&self, notification: &NSNotification)
unsafe fn textDidChange(&self, notification: &NSNotification)
Sourceimpl NSTextViewDelegate for SLComposeServiceViewController
impl NSTextViewDelegate for SLComposeServiceViewController
unsafe fn textView_clickedOnLink_atIndex( &self, text_view: &NSTextView, link: &AnyObject, char_index: usize, ) -> bool
unsafe fn textView_willChangeSelectionFromCharacterRange_toCharacterRange( &self, text_view: &NSTextView, old_selected_char_range: NSRange, new_selected_char_range: NSRange, ) -> NSRange
unsafe fn textView_willChangeSelectionFromCharacterRanges_toCharacterRanges( &self, text_view: &NSTextView, old_selected_char_ranges: &NSArray<NSValue>, new_selected_char_ranges: &NSArray<NSValue>, ) -> Retained<NSArray<NSValue>>
unsafe fn textView_shouldChangeTextInRanges_replacementStrings( &self, text_view: &NSTextView, affected_ranges: &NSArray<NSValue>, replacement_strings: Option<&NSArray<NSString>>, ) -> bool
unsafe fn textView_shouldChangeTypingAttributes_toAttributes( &self, text_view: &NSTextView, old_typing_attributes: &NSDictionary<NSString>, new_typing_attributes: &NSDictionary<NSString>, ) -> Retained<NSDictionary<NSString>>
unsafe fn textViewDidChangeSelection(&self, notification: &NSNotification)
unsafe fn textViewDidChangeTypingAttributes( &self, notification: &NSNotification, )
unsafe fn textView_willDisplayToolTip_forCharacterAtIndex( &self, text_view: &NSTextView, tooltip: &NSString, character_index: usize, ) -> Option<Retained<NSString>>
unsafe fn textView_completions_forPartialWordRange_indexOfSelectedItem( &self, text_view: &NSTextView, words: &NSArray<NSString>, char_range: NSRange, index: *mut isize, ) -> Retained<NSArray<NSString>>
unsafe fn textView_shouldChangeTextInRange_replacementString( &self, text_view: &NSTextView, affected_char_range: NSRange, replacement_string: Option<&NSString>, ) -> bool
unsafe fn textView_doCommandBySelector( &self, text_view: &NSTextView, command_selector: Sel, ) -> bool
unsafe fn textView_shouldSetSpellingState_range( &self, text_view: &NSTextView, value: isize, affected_char_range: NSRange, ) -> isize
unsafe fn undoManagerForTextView( &self, view: &NSTextView, ) -> Option<Retained<NSUndoManager>>
unsafe fn textView_candidatesForSelectedRange( &self, text_view: &NSTextView, selected_range: NSRange, ) -> Option<Retained<NSArray>>
unsafe fn textView_candidates_forSelectedRange( &self, text_view: &NSTextView, candidates: &NSArray<NSTextCheckingResult>, selected_range: NSRange, ) -> Retained<NSArray<NSTextCheckingResult>>
unsafe fn textView_shouldSelectCandidateAtIndex( &self, text_view: &NSTextView, index: usize, ) -> bool
unsafe fn textViewWritingToolsWillBegin(&self, text_view: &NSTextView)
unsafe fn textViewWritingToolsDidEnd(&self, text_view: &NSTextView)
unsafe fn textView_writingToolsIgnoredRangesInEnclosingRange( &self, text_view: &NSTextView, enclosing_range: NSRange, ) -> Retained<NSArray<NSValue>>
Sourceunsafe fn textView_clickedOnLink(
&self,
text_view: &NSTextView,
link: Option<&AnyObject>,
) -> bool
unsafe fn textView_clickedOnLink( &self, text_view: &NSTextView, link: Option<&AnyObject>, ) -> bool
Sourceimpl RefEncode for SLComposeServiceViewController
impl RefEncode for SLComposeServiceViewController
Sourceconst ENCODING_REF: Encoding = <NSViewController as ::objc2::RefEncode>::ENCODING_REF
const ENCODING_REF: Encoding = <NSViewController as ::objc2::RefEncode>::ENCODING_REF
impl DowncastTarget for SLComposeServiceViewController
impl Eq for SLComposeServiceViewController