Struct objc2_social::SLRequest
source · #[repr(C)]pub struct SLRequest { /* private fields */ }Available on crate feature
SLRequest only.Implementations
sourceimpl SLRequest
impl SLRequest
pub unsafe fn requestForServiceType_requestMethod_URL_parameters( service_type: Option<&NSString>, request_method: SLRequestMethod, url: Option<&NSURL>, parameters: Option<&NSDictionary> ) -> Option<Retained<SLRequest>>
pub unsafe fn account(&self) -> Option<Retained<ACAccount>>
Available on crate feature
objc2-accounts only.pub unsafe fn setAccount(&self, account: Option<&ACAccount>)
Available on crate feature
objc2-accounts only.pub unsafe fn requestMethod(&self) -> SLRequestMethod
pub unsafe fn URL(&self) -> Option<Retained<NSURL>>
pub unsafe fn parameters(&self) -> Option<Retained<NSDictionary>>
pub unsafe fn addMultipartData_withName_type_filename( &self, data: Option<&NSData>, name: Option<&NSString>, type: Option<&NSString>, filename: Option<&NSString> )
pub unsafe fn addMultipartData_withName_type( &self, data: Option<&NSData>, name: Option<&NSString>, type: Option<&NSString> )
pub unsafe fn preparedURLRequest(&self) -> Option<Retained<NSURLRequest>>
pub unsafe fn performRequestWithHandler(&self, handler: SLRequestHandler)
Available on crate feature
block2 only.Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.