#[repr(C)]pub struct SLComposeServiceViewController { /* private fields */ }SLComposeServiceViewController and crate feature objc2-app-kit and macOS only.Expand description
Implementations
Sourceimpl SLComposeServiceViewController
impl SLComposeServiceViewController
pub unsafe fn presentationAnimationDidFinish(&self)
pub unsafe fn textView(&self) -> Option<Retained<NSTextView>>
pub unsafe fn contentText(&self) -> Option<Retained<NSString>>
pub unsafe fn placeholder(&self) -> Retained<NSString>
Sourcepub unsafe fn setPlaceholder(&self, placeholder: Option<&NSString>)
pub unsafe fn setPlaceholder(&self, placeholder: Option<&NSString>)
Setter for placeholder.
pub unsafe fn didSelectPost(&self)
pub unsafe fn didSelectCancel(&self)
pub unsafe fn cancel(&self)
pub unsafe fn isContentValid(&self) -> bool
pub unsafe fn validateContent(&self)
pub unsafe fn charactersRemaining(&self) -> Option<Retained<NSNumber>>
Sourcepub unsafe fn setCharactersRemaining(
&self,
characters_remaining: Option<&NSNumber>,
)
pub unsafe fn setCharactersRemaining( &self, characters_remaining: Option<&NSNumber>, )
Setter for charactersRemaining.
Sourceimpl SLComposeServiceViewController
Methods declared on superclass NSViewController.
impl SLComposeServiceViewController
Methods declared on superclass NSViewController.
Sourceimpl SLComposeServiceViewController
Methods declared on superclass NSResponder.
impl SLComposeServiceViewController
Methods declared on superclass NSResponder.
Sourceimpl SLComposeServiceViewController
Methods declared on superclass NSObject.
impl SLComposeServiceViewController
Methods declared on superclass NSObject.
pub unsafe fn new(mtm: MainThreadMarker) -> Retained<Self>
Methods from Deref<Target = NSViewController>
pub unsafe fn nibName(&self) -> Option<Retained<NSString>>
NSResponder and NSNib only.pub unsafe fn nibBundle(&self) -> Option<Retained<NSBundle>>
NSResponder only.pub unsafe fn representedObject(&self) -> Option<Retained<AnyObject>>
NSResponder only.Sourcepub unsafe fn setRepresentedObject(
&self,
represented_object: Option<&AnyObject>,
)
Available on crate feature NSResponder only.
pub unsafe fn setRepresentedObject( &self, represented_object: Option<&AnyObject>, )
NSResponder only.Setter for representedObject.
pub unsafe fn title(&self) -> Option<Retained<NSString>>
NSResponder only.Sourcepub unsafe fn setTitle(&self, title: Option<&NSString>)
Available on crate feature NSResponder only.
pub unsafe fn setTitle(&self, title: Option<&NSString>)
NSResponder only.Setter for title.
pub unsafe fn view(&self) -> Retained<NSView>
NSResponder and NSView only.Sourcepub unsafe fn setView(&self, view: &NSView)
Available on crate features NSResponder and NSView only.
pub unsafe fn setView(&self, view: &NSView)
NSResponder and NSView only.Setter for view.
pub unsafe fn viewIfLoaded(&self) -> Option<Retained<NSView>>
NSResponder and NSView only.pub unsafe fn loadView(&self)
NSResponder only.pub unsafe fn loadViewIfNeeded(&self)
NSResponder only.pub unsafe fn commitEditingWithDelegate_didCommitSelector_contextInfo( &self, delegate: Option<&AnyObject>, did_commit_selector: Option<Sel>, context_info: *mut c_void, )
NSResponder only.pub unsafe fn commitEditing(&self) -> bool
NSResponder only.pub unsafe fn discardEditing(&self)
NSResponder only.pub unsafe fn viewDidLoad(&self)
NSResponder only.pub unsafe fn isViewLoaded(&self) -> bool
NSResponder only.pub unsafe fn viewWillAppear(&self)
NSResponder only.pub unsafe fn viewDidAppear(&self)
NSResponder only.pub unsafe fn viewWillDisappear(&self)
NSResponder only.pub unsafe fn viewDidDisappear(&self)
NSResponder only.pub unsafe fn preferredContentSize(&self) -> CGSize
NSResponder only.Sourcepub unsafe fn setPreferredContentSize(&self, preferred_content_size: CGSize)
Available on crate feature NSResponder only.
pub unsafe fn setPreferredContentSize(&self, preferred_content_size: CGSize)
NSResponder only.Setter for preferredContentSize.
pub unsafe fn updateViewConstraints(&self)
NSResponder only.pub unsafe fn viewWillLayout(&self)
NSResponder only.pub unsafe fn viewDidLayout(&self)
NSResponder only.pub unsafe fn presentViewController_animator( &self, view_controller: &NSViewController, animator: &ProtocolObject<dyn NSViewControllerPresentationAnimator>, )
NSResponder only.pub unsafe fn dismissViewController(&self, view_controller: &NSViewController)
NSResponder only.pub unsafe fn dismissController(&self, sender: Option<&AnyObject>)
NSResponder only.pub unsafe fn presentedViewControllers( &self, ) -> Option<Retained<NSArray<NSViewController>>>
NSResponder only.pub unsafe fn presentingViewController( &self, ) -> Option<Retained<NSViewController>>
NSResponder only.pub unsafe fn presentViewControllerAsSheet( &self, view_controller: &NSViewController, )
NSResponder only.pub unsafe fn presentViewControllerAsModalWindow( &self, view_controller: &NSViewController, )
NSResponder only.pub unsafe fn parentViewController(&self) -> Option<Retained<NSViewController>>
NSResponder only.pub unsafe fn childViewControllers(&self) -> Retained<NSArray<NSViewController>>
NSResponder only.Sourcepub unsafe fn setChildViewControllers(
&self,
child_view_controllers: &NSArray<NSViewController>,
)
Available on crate feature NSResponder only.
pub unsafe fn setChildViewControllers( &self, child_view_controllers: &NSArray<NSViewController>, )
NSResponder only.Setter for childViewControllers.
pub unsafe fn addChildViewController( &self, child_view_controller: &NSViewController, )
NSResponder only.pub unsafe fn removeFromParentViewController(&self)
NSResponder only.pub unsafe fn insertChildViewController_atIndex( &self, child_view_controller: &NSViewController, index: isize, )
NSResponder only.pub unsafe fn removeChildViewControllerAtIndex(&self, index: isize)
NSResponder only.pub unsafe fn preferredContentSizeDidChangeForViewController( &self, view_controller: &NSViewController, )
NSResponder only.pub unsafe fn viewWillTransitionToSize(&self, new_size: CGSize)
NSResponder only.pub unsafe fn extensionContext(&self) -> Option<Retained<NSExtensionContext>>
NSResponder only.pub unsafe fn sourceItemView(&self) -> Option<Retained<NSView>>
NSResponder and NSView only.Sourcepub unsafe fn setSourceItemView(&self, source_item_view: Option<&NSView>)
Available on crate features NSResponder and NSView only.
pub unsafe fn setSourceItemView(&self, source_item_view: Option<&NSView>)
NSResponder and NSView only.Setter for sourceItemView.
pub unsafe fn preferredScreenOrigin(&self) -> CGPoint
NSResponder only.Sourcepub unsafe fn setPreferredScreenOrigin(&self, preferred_screen_origin: CGPoint)
Available on crate feature NSResponder only.
pub unsafe fn setPreferredScreenOrigin(&self, preferred_screen_origin: CGPoint)
NSResponder only.Setter for preferredScreenOrigin.
pub unsafe fn preferredMinimumSize(&self) -> CGSize
NSResponder only.pub unsafe fn preferredMaximumSize(&self) -> CGSize
NSResponder only.Methods from Deref<Target = NSResponder>
pub unsafe fn nextResponder(&self) -> Option<Retained<NSResponder>>
Sourcepub unsafe fn setNextResponder(&self, next_responder: Option<&NSResponder>)
pub unsafe fn setNextResponder(&self, next_responder: Option<&NSResponder>)
Setter for nextResponder.
pub unsafe fn tryToPerform_with( &self, action: Sel, object: Option<&AnyObject>, ) -> bool
pub unsafe fn noResponderFor(&self, event_selector: Sel)
pub unsafe fn acceptsFirstResponder(&self) -> bool
pub unsafe fn becomeFirstResponder(&self) -> bool
pub unsafe fn resignFirstResponder(&self) -> bool
pub unsafe fn flushBufferedKeyEvents(&self)
pub unsafe fn showContextHelp(&self, sender: Option<&AnyObject>)
pub unsafe fn supplementalTargetForAction_sender( &self, action: Sel, sender: Option<&AnyObject>, ) -> Option<Retained<AnyObject>>
pub unsafe fn undoManager(&self) -> Option<Retained<NSUndoManager>>
pub unsafe fn presentError(&self, error: &NSError) -> bool
pub unsafe fn willPresentError(&self, error: &NSError) -> Retained<NSError>
pub unsafe fn performTextFinderAction(&self, sender: Option<&AnyObject>)
pub unsafe fn newWindowForTab(&self, sender: Option<&AnyObject>)
pub unsafe fn showWritingTools(&self, sender: Option<&AnyObject>)
pub unsafe fn performMnemonic(&self, string: &NSString) -> bool
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<NSResponder> for SLComposeServiceViewController
impl AsRef<NSResponder> for SLComposeServiceViewController
Sourcefn as_ref(&self) -> &NSResponder
fn as_ref(&self) -> &NSResponder
Sourceimpl AsRef<NSViewController> for SLComposeServiceViewController
impl AsRef<NSViewController> for SLComposeServiceViewController
Sourcefn as_ref(&self) -> &NSViewController
fn as_ref(&self) -> &NSViewController
Sourceimpl Borrow<NSResponder> for SLComposeServiceViewController
impl Borrow<NSResponder> for SLComposeServiceViewController
Sourcefn borrow(&self) -> &NSResponder
fn borrow(&self) -> &NSResponder
Sourceimpl Borrow<NSViewController> for SLComposeServiceViewController
impl Borrow<NSViewController> for SLComposeServiceViewController
Sourcefn borrow(&self) -> &NSViewController
fn borrow(&self) -> &NSViewController
Sourceimpl ClassType for SLComposeServiceViewController
impl ClassType for SLComposeServiceViewController
Sourceconst NAME: &'static str = "SLComposeServiceViewController"
const NAME: &'static str = "SLComposeServiceViewController"
Sourcetype Super = NSViewController
type Super = NSViewController
Sourcetype ThreadKind = <<SLComposeServiceViewController as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<SLComposeServiceViewController as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl NSEditor for SLComposeServiceViewController
impl NSEditor for SLComposeServiceViewController
unsafe fn discardEditing(&self)
unsafe fn commitEditing(&self) -> bool
unsafe fn commitEditingWithDelegate_didCommitSelector_contextInfo( &self, delegate: Option<&AnyObject>, did_commit_selector: Option<Sel>, context_info: *mut c_void, )
unsafe fn commitEditingAndReturnError(&self) -> Result<(), Retained<NSError>>
Sourceimpl NSObjectProtocol for SLComposeServiceViewController
impl NSObjectProtocol for SLComposeServiceViewController
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_refSourcefn isMemberOfClass(&self, cls: &AnyClass) -> bool
fn isMemberOfClass(&self, cls: &AnyClass) -> bool
Sourcefn respondsToSelector(&self, aSelector: Sel) -> bool
fn respondsToSelector(&self, aSelector: Sel) -> bool
Sourcefn conformsToProtocol(&self, aProtocol: &AnyProtocol) -> bool
fn conformsToProtocol(&self, aProtocol: &AnyProtocol) -> bool
Sourcefn debugDescription(&self) -> Retained<NSObject>
fn debugDescription(&self) -> Retained<NSObject>
Sourceimpl NSSeguePerforming for SLComposeServiceViewController
impl NSSeguePerforming for SLComposeServiceViewController
unsafe fn prepareForSegue_sender( &self, segue: &NSStoryboardSegue, sender: Option<&AnyObject>, )
unsafe fn performSegueWithIdentifier_sender( &self, identifier: &NSString, sender: Option<&AnyObject>, )
unsafe fn shouldPerformSegueWithIdentifier_sender( &self, identifier: &NSString, sender: Option<&AnyObject>, ) -> bool
Sourceimpl NSTextDelegate for SLComposeServiceViewController
impl NSTextDelegate for SLComposeServiceViewController
Sourceunsafe fn textShouldBeginEditing(&self, text_object: &NSText) -> bool
unsafe fn textShouldBeginEditing(&self, text_object: &NSText) -> bool
NSResponder and NSView only.Sourceunsafe fn textShouldEndEditing(&self, text_object: &NSText) -> bool
unsafe fn textShouldEndEditing(&self, text_object: &NSText) -> bool
NSResponder and NSView only.unsafe fn textDidBeginEditing(&self, notification: &NSNotification)
unsafe fn textDidEndEditing(&self, notification: &NSNotification)
unsafe fn textDidChange(&self, notification: &NSNotification)
Sourceimpl NSTextViewDelegate for SLComposeServiceViewController
impl NSTextViewDelegate for SLComposeServiceViewController
Sourceunsafe fn textView_clickedOnLink_atIndex(
&self,
text_view: &NSTextView,
link: &AnyObject,
char_index: usize,
) -> bool
unsafe fn textView_clickedOnLink_atIndex( &self, text_view: &NSTextView, link: &AnyObject, char_index: usize, ) -> bool
NSResponder and NSView only.Sourceunsafe fn textView_willChangeSelectionFromCharacterRange_toCharacterRange(
&self,
text_view: &NSTextView,
old_selected_char_range: NSRange,
new_selected_char_range: NSRange,
) -> NSRange
unsafe fn textView_willChangeSelectionFromCharacterRange_toCharacterRange( &self, text_view: &NSTextView, old_selected_char_range: NSRange, new_selected_char_range: NSRange, ) -> NSRange
NSResponder and NSView only.Sourceunsafe fn textView_willChangeSelectionFromCharacterRanges_toCharacterRanges(
&self,
text_view: &NSTextView,
old_selected_char_ranges: &NSArray<NSValue>,
new_selected_char_ranges: &NSArray<NSValue>,
) -> Retained<NSArray<NSValue>>
unsafe fn textView_willChangeSelectionFromCharacterRanges_toCharacterRanges( &self, text_view: &NSTextView, old_selected_char_ranges: &NSArray<NSValue>, new_selected_char_ranges: &NSArray<NSValue>, ) -> Retained<NSArray<NSValue>>
NSResponder and NSView only.Sourceunsafe fn textView_shouldChangeTextInRanges_replacementStrings(
&self,
text_view: &NSTextView,
affected_ranges: &NSArray<NSValue>,
replacement_strings: Option<&NSArray<NSString>>,
) -> bool
unsafe fn textView_shouldChangeTextInRanges_replacementStrings( &self, text_view: &NSTextView, affected_ranges: &NSArray<NSValue>, replacement_strings: Option<&NSArray<NSString>>, ) -> bool
NSResponder and NSView only.Sourceunsafe fn textView_shouldChangeTypingAttributes_toAttributes(
&self,
text_view: &NSTextView,
old_typing_attributes: &NSDictionary<NSString>,
new_typing_attributes: &NSDictionary<NSString>,
) -> Retained<NSDictionary<NSString>>
unsafe fn textView_shouldChangeTypingAttributes_toAttributes( &self, text_view: &NSTextView, old_typing_attributes: &NSDictionary<NSString>, new_typing_attributes: &NSDictionary<NSString>, ) -> Retained<NSDictionary<NSString>>
NSResponder and NSView only.unsafe fn textViewDidChangeSelection(&self, notification: &NSNotification)
unsafe fn textViewDidChangeTypingAttributes( &self, notification: &NSNotification, )
Sourceunsafe fn textView_willDisplayToolTip_forCharacterAtIndex(
&self,
text_view: &NSTextView,
tooltip: &NSString,
character_index: usize,
) -> Option<Retained<NSString>>
unsafe fn textView_willDisplayToolTip_forCharacterAtIndex( &self, text_view: &NSTextView, tooltip: &NSString, character_index: usize, ) -> Option<Retained<NSString>>
NSResponder and NSView only.Sourceunsafe fn textView_completions_forPartialWordRange_indexOfSelectedItem(
&self,
text_view: &NSTextView,
words: &NSArray<NSString>,
char_range: NSRange,
index: *mut isize,
) -> Retained<NSArray<NSString>>
unsafe fn textView_completions_forPartialWordRange_indexOfSelectedItem( &self, text_view: &NSTextView, words: &NSArray<NSString>, char_range: NSRange, index: *mut isize, ) -> Retained<NSArray<NSString>>
NSResponder and NSView only.Sourceunsafe fn textView_shouldChangeTextInRange_replacementString(
&self,
text_view: &NSTextView,
affected_char_range: NSRange,
replacement_string: Option<&NSString>,
) -> bool
unsafe fn textView_shouldChangeTextInRange_replacementString( &self, text_view: &NSTextView, affected_char_range: NSRange, replacement_string: Option<&NSString>, ) -> bool
NSResponder and NSView only.Sourceunsafe fn textView_doCommandBySelector(
&self,
text_view: &NSTextView,
command_selector: Sel,
) -> bool
unsafe fn textView_doCommandBySelector( &self, text_view: &NSTextView, command_selector: Sel, ) -> bool
NSResponder and NSView only.Sourceunsafe fn textView_shouldSetSpellingState_range(
&self,
text_view: &NSTextView,
value: isize,
affected_char_range: NSRange,
) -> isize
unsafe fn textView_shouldSetSpellingState_range( &self, text_view: &NSTextView, value: isize, affected_char_range: NSRange, ) -> isize
NSResponder and NSView only.Sourceunsafe fn undoManagerForTextView(
&self,
view: &NSTextView,
) -> Option<Retained<NSUndoManager>>
unsafe fn undoManagerForTextView( &self, view: &NSTextView, ) -> Option<Retained<NSUndoManager>>
NSResponder and NSView only.Sourceunsafe fn textView_candidatesForSelectedRange(
&self,
text_view: &NSTextView,
selected_range: NSRange,
) -> Option<Retained<NSArray>>
unsafe fn textView_candidatesForSelectedRange( &self, text_view: &NSTextView, selected_range: NSRange, ) -> Option<Retained<NSArray>>
NSResponder and NSView only.Sourceunsafe fn textView_candidates_forSelectedRange(
&self,
text_view: &NSTextView,
candidates: &NSArray<NSTextCheckingResult>,
selected_range: NSRange,
) -> Retained<NSArray<NSTextCheckingResult>>
unsafe fn textView_candidates_forSelectedRange( &self, text_view: &NSTextView, candidates: &NSArray<NSTextCheckingResult>, selected_range: NSRange, ) -> Retained<NSArray<NSTextCheckingResult>>
NSResponder and NSView only.Sourceunsafe fn textView_shouldSelectCandidateAtIndex(
&self,
text_view: &NSTextView,
index: usize,
) -> bool
unsafe fn textView_shouldSelectCandidateAtIndex( &self, text_view: &NSTextView, index: usize, ) -> bool
NSResponder and NSView only.Sourceunsafe fn textViewWritingToolsWillBegin(&self, text_view: &NSTextView)
unsafe fn textViewWritingToolsWillBegin(&self, text_view: &NSTextView)
NSResponder and NSView only.Sourceunsafe fn textViewWritingToolsDidEnd(&self, text_view: &NSTextView)
unsafe fn textViewWritingToolsDidEnd(&self, text_view: &NSTextView)
NSResponder and NSView only.Sourceunsafe fn textView_writingToolsIgnoredRangesInEnclosingRange(
&self,
text_view: &NSTextView,
enclosing_range: NSRange,
) -> Retained<NSArray<NSValue>>
unsafe fn textView_writingToolsIgnoredRangesInEnclosingRange( &self, text_view: &NSTextView, enclosing_range: NSRange, ) -> Retained<NSArray<NSValue>>
NSResponder and NSView only.Sourceunsafe fn textView_clickedOnLink(
&self,
text_view: &NSTextView,
link: Option<&AnyObject>,
) -> bool
unsafe fn textView_clickedOnLink( &self, text_view: &NSTextView, link: Option<&AnyObject>, ) -> bool
NSResponder and NSView only.Sourceimpl RefEncode for SLComposeServiceViewController
impl RefEncode for SLComposeServiceViewController
Sourceconst ENCODING_REF: Encoding = <NSViewController as ::objc2::RefEncode>::ENCODING_REF
const ENCODING_REF: Encoding = <NSViewController as ::objc2::RefEncode>::ENCODING_REF
impl DowncastTarget for SLComposeServiceViewController
impl Eq for SLComposeServiceViewController